Index — cocos v0.6.10 documentation

# Index – C

c (Circle attribute) (Matrix3 attribute) (Matrix4 attribute) (Sphere attribute) cache (Resource attribute) CallFunc (class in cocos.actions.instant_actions) CallFuncS (class in cocos.actions.instant_actions) Camera (class in cocos.camera) camera (CocosNode attribute) Camera3DAction (class in cocos.actions.camera_actions) CameraException Canvas (class in cocos.draw) capture_layer() (in module cocos.tiles) capture_tileset() (in module cocos.tiles) Cell (class in cocos.tiles) center() (Camera property) (HexCell property) (Rect property) (RectCell property) cfg (PythonInterpreterLayer attribute) check_status() (FramebufferObject method) children (CocosNode attribute) children_names (CocosNode attribute) Circle (class in cocos.euclid) circle_distance_circle() (in module cocos.collision_model) circle_overlaps_circle() (in module cocos.collision_model) CircleShape (class in cocos.collision_model) clamp() (in module cocos.collision_model) clear() (CollisionManager method) (CollisionManagerBruteForce method) (CollisionManagerGrid method) clippedBy() (Rect method) cocos module cocos.actions module cocos.actions.base_actions module cocos.actions.basegrid_actions module cocos.actions.camera_actions module cocos.actions.grid3d_actions module cocos.actions.instant_actions module cocos.actions.interval_actions module cocos.actions.move_actions module cocos.actions.quadmoveby_actions module cocos.actions.tiledgrid_actions module cocos.audio module cocos.audio.actions module cocos.audio.effect module cocos.audio.exceptions module cocos.audio.music module cocos.batch module cocos.camera module cocos.cocosnode module cocos.collision_model module cocos.compat module cocos.custom_clocks module cocos.director module cocos.draw module cocos.euclid module cocos.fps module cocos.framegrabber module cocos.gl_framebuffer_object module cocos.grid module | cocos.layer module cocos.layer.base_layers module cocos.layer.python_interpreter module cocos.layer.scrolling module cocos.layer.util_layers module cocos.mapcolliders module cocos.menu module cocos.particle module cocos.particle_systems module cocos.path module cocos.rect module cocos.scene module cocos.scenes module cocos.scenes.pause module cocos.scenes.sequences module cocos.scenes.transitions module cocos.shader module cocos.skeleton module cocos.sprite module cocos.text module cocos.tiles module cocos.utils module cocos.wired module CocosNode (class in cocos.cocosnode) collide() (TmxObjectLayer method) collide_bottom() (RectMapCollider method) collide_left() (RectMapCollider method) collide_map() (RectMapCollider method) (TmxObjectMapCollider method) collide_right() (RectMapCollider method) collide_top() (RectMapCollider method) CollisionManager (class in cocos.collision_model) CollisionManagerBruteForce (class in cocos.collision_model) CollisionManagerGrid (class in cocos.collision_model) Color (class in cocos.particle) color() (ColorLayer property) (Line property) color4_to_text() (in module cocos.tiles) color_modulate (Explosion attribute) (Fire attribute) (Fireworks attribute) (Flower attribute) (Galaxy attribute) (Meteor attribute) (ParticleSystem attribute) (Smoke attribute) (Spiral attribute) (Sun attribute) ColorLayer (class in cocos.layer.util_layers) ColorMenuItem (class in cocos.menu) ColorSkin (class in cocos.skeleton) complete_refresh() (FpsDisplay method) (FpsDisplaySimple method) conjugated() (Quaternion method) connect() (Circle method) (Geometry method) (Line2 method) (Line3 method) (Plane method) (Point2 method) (Point3 method) (Sphere method) contains() (Rect method) (Sprite method) Context (class in cocos.draw) copy() (AARectShape method) (Circle method) (CircleShape method) (Context method) (Cshape method) (Line2 method) (Line3 method) (Matrix3 method) (Matrix4 method) (Plane method) (Quaternion method) (Rect method) (Sphere method) (Vector2 method) (Vector3 method) CornerMoveTransition (class in cocos.scenes.transitions) CornerSwap (class in cocos.actions.quadmoveby_actions) create_element() (TextElement method) create_menu() (Menu method) cross() (Vector2 method) (Vector3 method) Cshape (class in cocos.collision_model)